from typing import *


class OutOfBoundsDatetime:
    def __init__(self, _0: str, /):
        """
        usage.xarray: 1
        """
        ...
